summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/modes.h4
-rw-r--r--include/protocol.h1
2 files changed, 3 insertions, 2 deletions
diff --git a/include/protocol.h b/include/protocol.h
index 385448662..9ff0167c9 100644
--- a/include/protocol.h
+++ b/include/protocol.h
@@ -222,6 +222,7 @@ class CoreExport IRCDProto : public Service
virtual bool IsChannelValid(const Anope::string &);
virtual bool IsIdentValid(const Anope::string &);
virtual bool IsHostValid(const Anope::string &);
+ virtual bool IsExtbanValid(const Anope::string &) { return false; }
};
class CoreExport MessageSource
diff --git a/include/modes.h b/include/modes.h
index a9957e332..bb329b5b4 100644
--- a/include/modes.h
+++ b/include/modes.h
@@ -401,11 +401,11 @@ class CoreExport Entry
Anope::string mask;
public:
unsigned short cidr_len;
- Anope::string nick, user, host;
+ Anope::string nick, user, host, real;
/** Constructor
* @param mode What mode this host is for, can be empty for unknown/no mode
* @param host A full nick!ident@host/cidr mask
*/
Entry(const Anope::string &mode, const Anope::string &host);
@@ -401,11 +401,11 @@ class CoreExport Entry
/** Constructor
* @param mode What mode this host is for, can be empty for unknown/no mode
- * @param host A full nick!ident@host/cidr mask
+ * @param host A full or poartial nick!ident@host/cidr#real name mask
*/
Entry(const Anope::string &mode, const Anope::string &host);